'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getLicenses = exports.isYarnInUse = undefined;

var _fs = require('fs');

var _path = require('path');

var _ldJsonstream = require('ld-jsonstream');

var _ldJsonstream2 = _interopRequireDefault(_ldJsonstream);

var _execFile = require('./exec-file');

var _execFile2 = _interopRequireDefault(_execFile);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const isYarnInUse = exports.isYarnInUse = (path = '.') => (0, _fs.existsSync)((0, _path.join)(path, 'node_modules', '.yarn-integrity'));

const getTable = async ldjson => new Promise((resolve, reject) => {
  let hit = false;
  const stream = new _ldJsonstream2.default();
  stream.on('data', ({ type, data }) => {
    if (type === 'table') {
      resolve(data);
      hit = true;
    }
  });
  stream.write(ldjson);
  if (!hit) reject(new Error('Received no chunk of type table'));
});

const getLicenses = exports.getLicenses = async (dev, cwd = '.') => {
  const jsonStream = await (0, _execFile2.default)(cwd, 'yarn', '--json', '--no-progress', '--silent', 'licenses', 'list', dev ? '--dev' : '--prod');
  // expect(json).to.have.property('type', 'table')
  // expect(json).to.have.property('data').that.is.an('object')
  // expect(data).to.have.property('head').that.is.an('array')
  // .that.includes.members(['Name', 'Version', 'License'])
  // expect(data).to.have.property('body').that.is.an('array')
  const data = await getTable(jsonStream);
  const { head, body } = data;
  const _name = head.indexOf('Name');
  const _version = head.indexOf('Version');
  const _license = head.indexOf('License');
  return body.map(module => {
    const name = module[_name];
    const version = module[_version];
    const license = module[_license];
    return { name, version, license };
  });
};